@@ -11,6 +11,7 @@ import numpy as np
 import pandas as pd
 from datasets import Dataset
 
+TEACHER_FORCING_PRE = "_TEACHERFORCING"
 SPECIAL_COL_SEP = "___"
 NUMERIC_NA_TOKEN = "@"
 INVALID_NUMS_RE = r"[^\-.0-9]"
@@ -327,6 +328,7 @@ def process_data(
     numeric_nparts=2,
     first_col_type=None,
     col_transform_data: Dict = None,
+    target_col: str = None,
 ) -> Tuple[pd.DataFrame, Dict]:
     # This should receive a dataframe with dtypes that have already been
     # properly categorized between numeric and categorical.
@@ -348,6 +350,15 @@ def process_data(
         except ValueError:
             pass
 
+    if target_col is not None:
+        assert first_col_type is None, "Implicit ordering of columns when teacher-forcing of target is used is not supported yet!"
+        tf_col_name = f"{TEACHER_FORCING_PRE}_{target_col}"
+        assert tf_col_name not in df.columns, f"The column name ({tf_col_name}) must not be in the raw data. Found instead..."
+
+        target_ser = df[target_col].copy()
+        target_ser.name = tf_col_name
+        df = pd.concat([target_ser, df], axis=1)
+
     # Rename the columns to encode the original order by adding a suffix of increasing
     # integer values.
     num_cols = len(str(len(df.columns)))
