@@ -1,7 +1,9 @@
+import os
 import math
 import random
 from typing import Any, List, Optional, Union
 
+import joblib
 import numpy as np
 import pandas as pd
 import sklearn
@@ -665,7 +667,7 @@ class SyntheticDataBench:
             # threshold.
             assert ((sensitivity_orig_frac_multiple + 2) * frac <= 1)
 
-        for _ in tqdm(range(num_bootstrap), desc="Bootstrap round"):
+        def bootstrap_inner_loop():
             if full_sensitivity:
                 original, test = train_test_split(train_data, test_size=2 * frac)
                 synthetic = test.iloc[: len(test) // 2]
@@ -683,20 +685,30 @@ class SyntheticDataBench:
 
                 assert synthetic.shape[0] == test.shape[0]
 
-            values.append(
-                SyntheticDataBench.compute_sensitivity_metric(
-                    original=original,
-                    synthetic=synthetic,
-                    test=test,
-                    qt_max=qt_max,
-                    qt_interval=qt_interval,
-                    distance=distance,
-                    tsvd=tsvd,
-                    max_col_nums=max_col_nums,
-                    use_ks=use_ks,
-                )
+            return SyntheticDataBench.compute_sensitivity_metric(
+                original=original,
+                synthetic=synthetic,
+                test=test,
+                qt_max=qt_max,
+                qt_interval=qt_interval,
+                distance=distance,
+                tsvd=tsvd,
+                max_col_nums=max_col_nums,
+                use_ks=use_ks,
             )
 
+        n_jobs = 1
+        if os.cpu_count() >= 4:
+            n_jobs = min(max(2, os.cpu_count() // 4), 16)
+
+        if n_jobs == 1:
+            for _ in tqdm(range(num_bootstrap), desc="Bootstrap round"):
+                values.append(bootstrap_inner_loop())
+        else:
+            print("Using parallel computation!!!")
+            with joblib.Parallel(n_jobs=n_jobs) as parallel:
+                values = parallel(joblib.delayed(bootstrap_inner_loop)() for _ in tqdm(range(num_bootstrap), desc="Bootstrap round"))
+
         print("Sensitivity threshold summary:")
         print(pd.Series(values).describe())
 
