@@ -21,6 +21,11 @@ from transformers.optimization import get_scheduler
 class SaveEpochEndCallback(TrainerCallback):
     """This callback forces a checkpoint save at each epoch end."""
 
+    def __init__(self, save_epochs: int = None) -> None:
+        super().__init__()
+
+        self.save_epochs = save_epochs
+
     def on_epoch_end(
         self,
         args: TrainingArguments,
@@ -28,7 +33,11 @@ class SaveEpochEndCallback(TrainerCallback):
         control: TrainerControl,
         **kwargs
     ):
-        control.should_save = True
+        if self.save_epochs is not None:
+            control.should_save = math.ceil(state.epoch) % self.save_epochs == 0
+        else:
+            control.should_save = True
+
         return control
 
 
@@ -42,6 +51,7 @@ class ResumableTrainer(Trainer):
     def __init__(
         self,
         target_epochs: int = None,
+        save_epochs: int = None,
         model: Union[PreTrainedModel, nn.Module] = None,
         args: TrainingArguments = None,
         data_collator: Optional[DataCollator] = None,
@@ -65,7 +75,7 @@ class ResumableTrainer(Trainer):
         if callbacks is None:
             callbacks = []
 
-        callbacks.append(SaveEpochEndCallback())
+        callbacks.append(SaveEpochEndCallback(save_epochs=save_epochs))
 
         super().__init__(
             model,
